import { Component, OnDestroy } from "@angular/core";
import { SidebarService } from "src/app/service/sidebar.service";
import { Subject } from "rxjs";
import { takeUntil } from "rxjs/operators";
import { AuthService } from "src/app/service/auth.service";

@Component({
  selector: "app-root",
  templateUrl: "./app.component.html",
  styleUrl: "./app.component.scss",
})
export class AppComponent implements OnDestroy {
  showSidebar = false;
  isLoggedIn = false;
  unsubscribe$ = new Subject<void>();

  constructor(
    private sidebar: SidebarService,
    private auth: AuthService,
  ) {
    this.auth.loadUser();

    this.auth.user$.pipe(takeUntil(this.unsubscribe$)).subscribe((user) => {
      this.isLoggedIn = user !== null && user !== undefined;
    });

    this.sidebar.visible$
      .pipe(takeUntil(this.unsubscribe$))
      .subscribe((visible) => {
        this.showSidebar = visible;
      });
  }

  ngOnDestroy() {
    this.unsubscribe$.next();
    this.unsubscribe$.complete();
  }
}
